Transition

Enum Transition 

pub enum Transition {
Show 82 variants Angular { starting_angle: f32, }, Bounce { shadow_height: f32, bounces: f32, shadow_colour: [f32; 4], }, BowTieHorizontal, BowTieVertical, BowTieWithParameter { adjust: f32, reverse: bool, }, Burn { color: [f32; 3], }, ButterflyWaveScrawler { amplitude: f32, waves: f32, color_separation: f32, }, CannabisLeaf, Circle { center: [f32; 2], background_color: [f32; 3], }, CircleCrop { background_color: [f32; 4], }, CircleOpen { smoothness: f32, opening: bool, }, ColorDistance { power: f32, }, ColorPhase { from_step: [f32; 4], to_step: [f32; 4], }, CoordFromIn, CrazyParametricFun { a: f32, b: f32, amplitude: f32, smoothness: f32, }, Crosshatch { center: [f32; 2], threshold: f32, fade_edge: f32, }, CrossWarp, CrossZoom { strength: f32, }, Cube { perspective: f32, unzoom: f32, reflection: f32, floating: f32, }, Directional { direction: [f32; 2], }, DirectionalEasing { direction: [f32; 2], }, DirectionalWarp { direction: [f32; 2], }, DirectionalWipe { smoothness: f32, direction: [f32; 2], }, Displacement { displacement_map: AnyImageNode, strength: f32, }, DoomScreen { bars: i32, amplitude: f32, noise: f32, frequency: f32, drip_scale: f32, }, Doorway { reflection: f32, perspective: f32, depth: f32, }, Dreamy, DreamyZoom { rotation: f32, scale: f32, }, FadeColor { color_phase: f32, color: [f32; 3], }, Fade, FadeGrayscale { intensity: f32, }, FilmBurn { seed: f32, }, Flyeye { size: f32, zoom: f32, color_separation: f32, }, GlitchDisplace, GlitchMemories, GridFlip { pause: f32, size: [i32; 2], background_color: [f32; 4], divider_width: f32, randomness: f32, }, Heart, Hexagonalize { steps: i32, horizontal_hexagons: f32, }, InvertedPageCurl, Kaleidoscope { speed: f32, angle: f32, power: f32, }, LeftRight, LinearBlur { intensity: f32, }, Luma { luma_map: AnyImageNode, }, LuminanceMelt { direction: bool, threshold: f32, above: bool, }, Morph { strength: f32, }, Mosaic { end: [i32; 2], }, Multiply, Overexposure { strength: f32, }, Perlin { scale: f32, smoothness: f32, seed: f32, }, Pinwheel { speed: f32, }, Pixelize { steps: i32, squares_min: [i32; 2], }, PolarFunction { segments: i32, }, PolkaDotsCurtain { dots: f32, center: [f32; 2], }, PowerKaleido { scale: f32, z: f32, speed: f32, }, Radial { smoothness: f32, }, RandomNoisex, RandomSquares { smoothness: f32, size: [i32; 2], }, Ripple { amplitude: f32, speed: f32, }, Rotate, RotateScale { rotations: f32, center: [f32; 2], background_color: [f32; 4], scale: f32, }, ScaleIn, SimpleZoom { zoom_quickness: f32, }, SquaresWire { smoothness: f32, squares: [i32; 2], direction: [f32; 2], }, Squeeze { color_separation: f32, }, StereoViewer { zoom: f32, corner_radius: f32, }, Swap { reflection: f32, perspective: f32, depth: f32, }, Swirl, TangentMotionBlur, TopBottom, TvStatic { offset: f32, }, UndulatingBurnOut { smoothness: f32, center: [f32; 2], color: [f32; 3], }, WaterDrop { amplitude: f32, speed: f32, }, Wind { size: f32, }, WindowBlinds, WindowSlice { count: f32, smoothness: f32, }, WipeDown, WipeLeft, WipeRight, WipeUp, ZoomInCircles, ZoomLeftWipe { zoom_quickness: f32, }, ZoomRightWipe { zoom_quickness: f32, },
}

Variants



Angular

Fields

starting_angle: f32


Bounce

Fields

shadow_height: f32
bounces: f32
shadow_colour: [f32; 4]


BowTieHorizontal



BowTieVertical



BowTieWithParameter

Fields

adjust: f32
reverse: bool


Burn

Fields

color: [f32; 3]


ButterflyWaveScrawler

Fields

amplitude: f32
waves: f32
color_separation: f32


CannabisLeaf



Circle

Fields

center: [f32; 2]
background_color: [f32; 3]


CircleCrop

Fields

background_color: [f32; 4]


CircleOpen

Fields

smoothness: f32
opening: bool


ColorDistance

Fields

power: f32


ColorPhase

Fields

from_step: [f32; 4]
to_step: [f32; 4]


CoordFromIn



CrazyParametricFun

Fields

amplitude: f32
smoothness: f32


Crosshatch

Fields

center: [f32; 2]
threshold: f32
fade_edge: f32


CrossWarp



CrossZoom

Fields

strength: f32


Cube

Fields

perspective: f32
unzoom: f32
reflection: f32
floating: f32


Directional

Fields

direction: [f32; 2]


DirectionalEasing

Fields

direction: [f32; 2]


DirectionalWarp

Fields

direction: [f32; 2]


DirectionalWipe

Fields

smoothness: f32
direction: [f32; 2]


Displacement

Fields

displacement_map: AnyImageNode
strength: f32


DoomScreen

Fields

bars: i32

Number of total bars/columns

amplitude: f32

Multiplier for speed ratio. 0 = no variation when going down, higher = some elements go much faster

noise: f32

Further variations in speed. 0 = no noise, 1 = super noisy (ignore frequency)

frequency: f32

Speed variation horizontally. the bigger the value, the shorter the waves

drip_scale: f32

How much the bars seem to “run” from the middle of the screen first (sticking to the sides). 0 = no drip, 1 = curved drip



Doorway

Fields

reflection: f32
perspective: f32
depth: f32


Dreamy



DreamyZoom

Fields

rotation: f32

In degrees

scale: f32

Multiplier



FadeColor

Fields

color_phase: f32

if 0.0, there is no black phase, if 0.9, the black phase is very important

color: [f32; 3]


Fade



FadeGrayscale

Fields

intensity: f32

If 0.0, the image turns grayscale directly; if 0.9, the grayscale transition phase is very important.



FilmBurn

Fields

seed: f32


Flyeye

Fields

size: f32
zoom: f32
color_separation: f32


GlitchDisplace



GlitchMemories



GridFlip

Fields

pause: f32
size: [i32; 2]
background_color: [f32; 4]
divider_width: f32
randomness: f32


Heart



Hexagonalize

Fields

steps: i32
horizontal_hexagons: f32


InvertedPageCurl



Kaleidoscope

Fields

speed: f32
angle: f32
power: f32


LeftRight



LinearBlur

Fields

intensity: f32


Luma

Fields

luma_map: AnyImageNode


LuminanceMelt

Fields

direction: bool

Direction of movement: false for up, true for down.

threshold: f32

Luminance threshold.

above: bool

Whether movement takes effect above or below the luminance threshold.



Morph

Fields

strength: f32


Mosaic

Fields

end: [i32; 2]


Multiply



Overexposure

Fields

strength: f32


Perlin

Fields

scale: f32
smoothness: f32
seed: f32


Pinwheel

Fields

speed: f32


Pixelize

Fields

steps: i32

Zero disables stepping

squares_min: [i32; 2]

Minimum number of squares (when the effect is at its higher level)



PolarFunction

Fields

segments: i32


PolkaDotsCurtain

Fields

dots: f32
center: [f32; 2]


PowerKaleido

Fields

scale: f32
speed: f32


Radial

Fields

smoothness: f32


RandomNoisex



RandomSquares

Fields

smoothness: f32
size: [i32; 2]


Ripple

Fields

amplitude: f32
speed: f32


Rotate



RotateScale

Fields

rotations: f32
center: [f32; 2]
background_color: [f32; 4]
scale: f32


ScaleIn



SimpleZoom

Fields

zoom_quickness: f32


SquaresWire

Fields

smoothness: f32
squares: [i32; 2]
direction: [f32; 2]


Squeeze

Fields

color_separation: f32


StereoViewer

Fields

zoom: f32

How much to zoom (out) for the effect ~ 0.5 - 1.0

corner_radius: f32

Corner radius as a fraction of the image height



Swap

Fields

reflection: f32
perspective: f32
depth: f32


Swirl



TangentMotionBlur



TopBottom



TvStatic

Fields

offset: f32


UndulatingBurnOut

Fields

smoothness: f32
center: [f32; 2]
color: [f32; 3]


WaterDrop

Fields

amplitude: f32
speed: f32


Wind

Fields

size: f32


WindowBlinds



WindowSlice

Fields

count: f32
smoothness: f32


WipeDown



WipeLeft



WipeRight



WipeUp



ZoomInCircles



ZoomLeftWipe

Fields

zoom_quickness: f32


ZoomRightWipe

Fields

zoom_quickness: f32