BitmapFont

Struct BitmapFont 

pub struct BitmapFont { /* private fields */ }
Holds a decoded bitmap Font.

Implementations

Source

impl BitmapFont

pub fn new( device: &Device, font: BMFont, pages: impl Into<Vec<Arc<Image>>>, ) -> Result<Self>

Creates a bitmap font renderer from decoded font metadata and page images.

pub fn measure(&self, text: &str) -> ([i32; 2], [u32; 2])

Returns the position and area, in pixels, required to render the given text.

NOTE: The ‘start’ of the render area is at the zero coordinate, however it may extend into the negative x direction due to ligatures.

pub fn print( &mut self, graph: &mut Graph, image: impl Into<AnyImageNode>, x: f32, y: f32, color: impl Into<BitmapGlyphColor>, text: impl AsRef<str>, )

Prints text at the given position using the default scale factor of 1.0.

pub fn print_scale( &mut self, graph: &mut Graph, image: impl Into<AnyImageNode>, x: f32, y: f32, color: impl Into<BitmapGlyphColor>, text: impl AsRef<str>, scale: f32, )

Prints text at the given position using a caller-specified scale factor.

pub fn print_scale_scissor( &mut self, graph: &mut Graph, image: impl Into<AnyImageNode>, x: f32, y: f32, color: impl Into<BitmapGlyphColor>, text: impl AsRef<str>, scale: f32, scissor: Option<(i32, i32, u32, u32)>, )

Prints text with an optional scissor rectangle and caller-specified scale factor.