TransitionPipeline

Struct TransitionPipeline 

pub struct TransitionPipeline { /* private fields */ }
Cache and lazily create transition compute pipelines on demand.

Implementations

Source

impl TransitionPipeline

pub fn new(device: &Device) -> Self

Creates an empty transition pipeline cache for the given device.

pub fn apply( &mut self, graph: &mut Graph, a_image: impl Into<AnyImageNode>, b_image: impl Into<AnyImageNode>, transition: Transition, progress: f32, ) -> ImageLeaseNode

Applies a transition between two images and returns a pooled destination image.

pub fn apply_to( &mut self, graph: &mut Graph, a_image: impl Into<AnyImageNode>, b_image: impl Into<AnyImageNode>, dest_image: impl Into<AnyImageNode>, transition: Transition, progress: f32, )

Applies a transition between two images into an existing destination image.