pub struct ComputePresenter(/* private fields */);Expand description
Compute-based presenter for copying one or two images into a swapchain image.
Implementations
Sourceimpl ComputePresenter
impl ComputePresenter
Sourcepub fn new(device: &Device) -> Result<Self, DriverError>
pub fn new(device: &Device) -> Result<Self, DriverError>
Creates compute pipelines used to present images into a swapchain target.
Sourcepub fn present_image(
&self,
graph: &mut Graph,
image: impl Into<AnyImageNode>,
swapchain: SwapchainImageNode,
)
pub fn present_image( &self, graph: &mut Graph, image: impl Into<AnyImageNode>, swapchain: SwapchainImageNode, )
Presents a single source image to the given swapchain image using a compute shader.
Sourcepub fn present_images(
&self,
graph: &mut Graph,
top_image: impl Into<AnyImageNode>,
bottom_image: impl Into<AnyImageNode>,
swapchain: SwapchainImageNode,
)
pub fn present_images( &self, graph: &mut Graph, top_image: impl Into<AnyImageNode>, bottom_image: impl Into<AnyImageNode>, swapchain: SwapchainImageNode, )
Presents two stacked source images to the given swapchain image using a compute shader.