pub struct TransitionPipeline { /* private fields */ }Expand description
Cache and lazily create transition compute pipelines on demand.
Implementations
Sourceimpl TransitionPipeline
impl TransitionPipeline
Sourcepub fn new(device: &Device) -> Self
pub fn new(device: &Device) -> Self
Creates an empty transition pipeline cache for the given device.
Sourcepub fn apply(
&mut self,
graph: &mut Graph,
a_image: impl Into<AnyImageNode>,
b_image: impl Into<AnyImageNode>,
transition: Transition,
progress: f32,
) -> ImageLeaseNode
pub fn apply( &mut self, graph: &mut Graph, a_image: impl Into<AnyImageNode>, b_image: impl Into<AnyImageNode>, transition: Transition, progress: f32, ) -> ImageLeaseNode
Applies a transition between two images and returns a pooled destination image.
Sourcepub fn apply_to(
&mut self,
graph: &mut Graph,
a_image: impl Into<AnyImageNode>,
b_image: impl Into<AnyImageNode>,
dest_image: impl Into<AnyImageNode>,
transition: Transition,
progress: f32,
)
pub fn apply_to( &mut self, graph: &mut Graph, a_image: impl Into<AnyImageNode>, b_image: impl Into<AnyImageNode>, dest_image: impl Into<AnyImageNode>, transition: Transition, progress: f32, )
Applies a transition between two images into an existing destination image.